@@ -379,7 +379,7 @@ create_archive_stream() {
 		"$TAR")
 			# --exclude "${package_dir}"/catalog 
 			# --exclude "${package_dir}"/catalog/\* 
-			"${TAR}" cf - ${TAR_FORMAT_OPTIONS} --files-from=- --no-recursion \
+			"${TAR}" cf - ${TAR_FORMAT_OPTIONS} --no-recursion --files-from=- \
 			${GNU_TAR_OWNER_OPTIONS} 
 			;;
 		"$PAX")
