@@ -74,6 +74,27 @@ void * malloc_fprintf(int sz, const char *format, ...);
 /* #define SWBISNEEDDEBUG 1 */
 #undef SWBISNEEDDEBUG
 
+#undef DEBUG_WITH_PID
+#define DEBUG_WITH_PID 1
+
+#ifdef DEBUG_WITH_PID
+#define SWBISERROR3(class, format, arg1, arg2) { \
+	\
+	fprintf(stderr, class "[%d]: %18s:%-5d , %s : " format "\n", (int)0,\
+		__FILE__, __LINE__, __FUNCTION__,  arg1, arg2); \
+	}
+#define SWBISERROR2(class, format, arg) { \
+	\
+	fprintf(stderr, class "[%d]: %18s:%-5d , %s : " format "\n", (int)0,\
+		__FILE__, __LINE__, __FUNCTION__, arg); \
+	}
+#define SWBISERROR(class, format) { \
+	\
+	fprintf(stderr, class "[%d]: %18s:%-5d , %s : " format "\n", (int)0,\
+		__FILE__, __LINE__, __FUNCTION__); \
+	}
+#else
+
 
 #define SWBISERROR3(class, format, arg1, arg2) { \
 	\
@@ -85,12 +106,14 @@ void * malloc_fprintf(int sz, const char *format, ...);
 	fprintf(stderr, class "[%d]: %18s:%-5d , %s : " format "\n", (int)getpid(),\
 		__FILE__, __LINE__, __FUNCTION__, arg); \
 	}
-
 #define SWBISERROR(class, format) { \
 	\
 	fprintf(stderr, class "[%d]: %18s:%-5d , %s : " format "\n", (int)getpid(),\
 		__FILE__, __LINE__, __FUNCTION__); \
 	}
+#endif
+
+
 
 
 
