@@ -179,7 +179,6 @@ fprintf(fp, "%s",
 
 fprintf(fp , "%s",
 
-
 "\n"
 " Basic Mode Control:\n"
 "\n"
@@ -206,12 +205,16 @@ fprintf(fp , "%s",
 "        or   -W option[=option_argument],option...\n"
 "        or   --option[=option_argument]\n"
 "\n"
-"      --noop              Legal option with no effect\n"
 "      --show-options      Show the extended options and exit\n"
 "      --show-options-files   Show the options files that will be parsed.\n"
-"      --no-defaults-files    Do not read any defaults files.\n"
 "\n"
-" Internal Operation Controls:\n"
+"  Operational Options:\n"
+"     --force-locks  ignore locking, and remove existing lock.\n"
+"     --sig-level=N  N=0,1, or 2,.. number of sigs required\n"
+"     --noop              Legal option with no effect\n"
+"     --no-defaults-file        Do not read any defaults files.\n"
+"\n"
+"  Target and Remote connection options\n"
 "\n"
 "      --remote-shell=NAME  NAME is the client \"rsh\" or \"ssh\"(default).\n"
 "      --no-remote-kill     Do not execute a kill command. Normally a kill\n"
@@ -243,7 +246,7 @@ fprintf(fp, "%s",
 "               ~/.swdefaults\n"
 "        Override values in defaults file.\n"
 "        Command Line Syntax : -x option=option_argument [-x ...]\n"
-"            or : -x \"option=option_argument  ...\"\n"
+"            or : -W \"option=option_argument  ...\"\n"
 "   distribution_target_directory   = -	     # Stdin\n"
 "   installed_software_catalog  = var/lib/swbis/catalog\n"
 "   one_liner                   = files|products\n"
@@ -539,7 +542,7 @@ main_sig_handler(int signum)
 }
 
 static
-void
+int
 apply_usage_restrictions(char * source_type, GB * G,
 			char * current_arg)
 {
@@ -580,12 +583,13 @@ apply_usage_restrictions(char * source_type, GB * G,
 
 	if (val) {
 		sw_e_msg(G, "invalid usage or specified target type is unsupported\n");
-		main_sig_handler(SIGTERM);
+		/* main_sig_handler(SIGTERM);
 		swc_shutdown_logger(G, SIGABRT);
-		LCEXIT(1);
+		*/
+		/* LCEXIT(1); */
 	}
 
-	return;
+	return val;
 }
 
 static
@@ -613,6 +617,7 @@ main(int argc, char **argv)
 {
 	int c;
 	int ret;
+	int uret;
 	int optret = 0;
 	int target_fdar[3];
 	int source_fdar[3];
@@ -683,6 +688,8 @@ main(int argc, char **argv)
 	int * p_do_progressmeter;
 	int make_master_raw = 1;
 	int is_local_stdin_seekable = 0;
+	int tmpret;
+	int tmp_status;
 	int nullfd;
 	int testnum = 0;
 	int f_retval = 0;
@@ -1049,7 +1056,7 @@ main(int argc, char **argv)
 	while (1) {
 		int option_index = 0;
 
-		c = ugetopt_long(argc, argv, "a:c:df:t:rl:Vvs:X:x:W:", 
+		c = ugetopt_long(argc, argv, "Aa:c:df:t:rl:Vvs:X:x:W:", 
 					main_long_options, &option_index);
 		if (c == -1) break;
 
@@ -1067,6 +1074,10 @@ main(int argc, char **argv)
 			}
 			swlist_blist_attr_add(BL, current_opt_level, optarg);
 			break;
+		case 'A':
+			wopt_forward_agent = CHARTRUE;
+			set_opta(opta, SW_E_swbis_forward_agent, wopt_forward_agent);
+			break;
 		case 'c':
 			opt_catalog_dest_dir = strdup(optarg);
 			BL->catalogM = strdup(optarg);
@@ -1850,8 +1861,9 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 		
 		/* More policy and sanity checks */
 
+		E_DEBUG("1");
 		apply_usage_restrictions(NULL, G, target_path);
-
+		E_DEBUG("");
 		if (strcmp(target_path, "-") == 0 && target_nhops >= 1) {
 			/* error cannot write to stdout except on localhost */
 			sw_e_msg(G, "invalid target spec\n");
@@ -1976,6 +1988,7 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 					target_loop_count, 
 					target_success_count));
 			}
+			E_DEBUG2("ss_pid=%d", (int)ss_pid);
 
 			/* Signal Check */
 			swc_check_for_current_signals(G, __LINE__, wopt_no_remote_kill);
@@ -2003,6 +2016,7 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 				G->g_pid_array, 
 				&G->g_pid_array_len, 
 				G->g_verboseG);
+			E_DEBUG("AB");
 
 			if (target_pump_pid > 0) {
 				/* This is the child of slave 
@@ -2081,7 +2095,7 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 		sw_d_msg(G, "source write pid: %d\n", source_write_pid);
 
 		if (source_write_pid > 0) {
-			E_DEBUG("");
+			E_DEBUG("source_write_pid > 0");
 			sw_d_msg(G, "waiting on source script pid\n");
 
 			/* Wait on the target script  */
@@ -2109,10 +2123,38 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 
 			if (ret < 0) {
 				/* Error, start message indicated failure */
+				E_DEBUG("ABC");
+
+				/*
+				 * This is (may be) the failure path for ssh authentication
+				 * failure.
+				 */
+		
+				/*
+				 * See if the ssh command has finished.
+				 */
+				if (swlib_wait_on_pid_with_timeout(ss_pid, &tmp_status, 0 /*flags*/, 1/*verbose_level*/, 3 /* Seconds */) > 0) {
+					/*
+					 * Store the result in the status array.
+					 */
+					SWLIB_ASSERT(
+						swlib_update_pid_status(ss_pid, tmp_status,
+							G->g_pid_array, G->g_status_array, G->g_pid_array_len) == 0);
+				}
+				E_DEBUG("ABCD");
+				if (WIFEXITED(tmp_status)) {
+					/*
+					 * This is the exit status of ssh (or rsh)
+					 */
+					tmpret = WEXITSTATUS(tmp_status);
+					swpl_agent_fail_message(G, current_arg, tmpret);
+				} else {
+					sw_e_msg(G, "SW_INTERNAL_ERROR for target %s in file %s at line %d\n",
+						current_arg, __FILE__, __LINE__);
+				}
+				E_DEBUG("ABCDE");
 				LC_RAISE(SIGTERM);
-				/* Signal Check */
 				swc_check_for_current_signals(G, __LINE__, wopt_no_remote_kill);
-				sw_e_msg(G, "read_start_ctl_message error (loc=start)\n");
 				LCEXIT(sw_exitval(G, target_loop_count, target_success_count));
 			}
 
@@ -2247,7 +2289,7 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 			}
 			E_DEBUG("");
 		} else if (source_write_pid == 0) {
-			E_DEBUG("");
+			E_DEBUG("source_write_pid == 0");
 			/* Fork did not happen.
 			   This happens when local_stdin is set.  */
 			;
@@ -2301,8 +2343,9 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 				xx_specs = swpl_get_dependency_specs(G, xx_swi, SW_A_prerequisites, 0, 0);
 				show_all_sw_selections(xx_specs, 2);
 			} else {
-				E_DEBUG("");
+				E_DEBUG("2");
 				apply_usage_restrictions("archive", G, "");
+				E_DEBUG("");
 				swgp_signal(SIGINT, main_sig_handler);
 				ret = swlist_list_distribution_archive(G,
 						opta,
@@ -2346,8 +2389,9 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 			   software selections */
 
 			/** DEBUG: show_all_sw_selections(swspecs, 2); */
+			E_DEBUG("3");
+			uret = apply_usage_restrictions("dir", G, "");
 			E_DEBUG("");
-			apply_usage_restrictions("dir", G, "");
 
 			isc_script_buf = strob_open(10);
 		
@@ -2355,18 +2399,22 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 
 			/* Handle the SWBIS_TS_uts task shell */
 			ret = swpl_get_utsname_attributes(G, swicol, uts, target_fdar[1], G->g_swi_event_fd);
-			if (ret != 0) {
-				abort_script(swicol, G, target_fdar[1]);
+			if (ret != 0 || uret != 0) {
+				swicol_set_master_alarm(swicol);
+				swicol_set_task_idstring(swicol, SWBIS_TS_Abort);
 				ret = swpl_send_abort(swicol, target_fdar[1], G->g_swi_event_fd, "");
 				f_retval++;
+				E_DEBUG("goto ENTER_WITH_FAILURE");
+				goto ENTER_WITH_FAILURE;
+			} else {
+
+				/* Send a gratuitous task shell that does nothing
+				   successfully, this is here as a test only. */
+
+				ret = swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
+						SWBIS_TS_Do_nothing ": testing 123");
 			}
 			swc_check_for_current_signals(G, __LINE__, wopt_no_remote_kill);
-
-			/* Send a gratuitous task shell that does nothing
-			   successfully, this is here as a test only. */
-			ret = swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
-						SWBIS_TS_Do_nothing ": testing 123");
-
 			uts_attr_mode = (
 				num_cmd_line_swspecs == 0 &&
 				BL->has_soc_attributesM == 0 &&
@@ -2776,6 +2824,7 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 							target_path,
 							target_nhops,
 							target_fdar[1] /* G->g_t_efd*/ );
+				E_DEBUG2("swlist_list_distribution_archive ret=[%d]", ret);
 				if (ret) {
 					E_DEBUG("");
 					sw_e_msg(G, "error decoding source\n");
@@ -2822,6 +2871,7 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 
 		/* Signal Check */
 		swc_check_for_current_signals(G, __LINE__, wopt_no_remote_kill);
+		E_DEBUG("");
 
 ENTER_WITH_FAILURE:
 		if (swicol_get_master_alarm_status(swicol) == 0 && source_write_pid > 0 ) {
@@ -2834,11 +2884,13 @@ ENTER_WITH_FAILURE:
 			shcmd_close(kill_sshcmd[0]);
 			kill_sshcmd[0] = (SHCMD*)NULL;
 		}
+		E_DEBUG("");
 
 		if (target_kill_sshcmd[0]) {
 			shcmd_close(target_kill_sshcmd[0]);
 			target_kill_sshcmd[0] = (SHCMD*)NULL;
 		}
+		E_DEBUG("");
 
 		/* Now close down  */
 			
@@ -2848,6 +2900,7 @@ ENTER_WITH_FAILURE:
 		E_DEBUG("");
 		swc_check_for_current_signals(G, __LINE__, wopt_no_remote_kill);
 		close(target_fdar[0]);
+		E_DEBUG("");
 		if (target_fdar[1] != STDOUT_FILENO) 
 			close(target_fdar[1]);
 
@@ -2958,9 +3011,10 @@ TARGET1:
 	E_DEBUG("");
 	close(G->g_swevent_fd);
 	close(G->g_swi_event_fd);
-	f_retval = swc_shutdown_logger(G, 0);
-	E_DEBUG("");
-	if (f_retval) return 1;
-	if (reqs_failed) return 3;
-	return(sw_exitval(G, target_loop_count, target_success_count));	
+	if (G->g_logger_pid > 0) {
+		f_retval = swc_shutdown_logger(G, 0);
+		if (f_retval) exit(1);
+	}
+	if (reqs_failed) exit(3);
+	exit(sw_exitval(G, target_loop_count, target_success_count));	
 }
