@@ -420,7 +420,7 @@ write_annex_date_attribute (GB * G, SWICAT_E * e, BLIST * BL, char * cl_target_t
 	if (!line) goto error_out;
 	value = swheaderline_get_value(line, (int *)NULL);
 	if (!value) goto error_out;
-    	uli = swlib_atoul(value, &result);
+    	uli = swlib_atoul(value, &result, (char**)NULL);
 	tm = (time_t)uli;
 	/* ctime_r(&tm, buf); */
         strncpy(buf, asctime(localtime(&tm)), sizeof(buf) - 1);
@@ -638,6 +638,10 @@ swlist_write_source_copy_script2(GB * G,
 	strob_strcpy(buffer_new, "");
 	if (strcmp(get_opta(G->optaM, SW_E_swbis_shell_command), "detect") == 0) {
 		swpl_bashin_detect(buffer_new);
+	} else if (strcmp(get_opta(G->optaM, SW_E_swbis_shell_command), "posix") == 0) {
+		swpl_bashin_posixsh(buffer_new);
+	} else {
+		swpl_bashin_testsh(buffer_new, get_opta(G->optaM, SW_E_swbis_shell_command));
 	}
 
 	/* Now here is the script */
