@@ -532,6 +532,10 @@ swremove_write_source_copy_script2(GB * G,
 	strob_strcpy(buffer_new, "");
 	if (strcmp(get_opta(G->optaM, SW_E_swbis_shell_command), "detect") == 0) {
 		swpl_bashin_detect(buffer_new);
+	} else if (strcmp(get_opta(G->optaM, SW_E_swbis_shell_command), "posix") == 0) {
+		swpl_bashin_posixsh(buffer_new);
+	} else {
+		swpl_bashin_testsh(buffer_new, get_opta(G->optaM, SW_E_swbis_shell_command));
 	}
 
 	/* Now here is the script */
