@@ -39,9 +39,25 @@
 #define DEFAULT_PAX_REM "tar"
 #endif
 
+#define SWVERIFY_OUTF_RPM	1  /* selected by --output-form=rpm */
+#define SWVERIFY_OUTF_DIFF	0  /* default */
+#define SWVERIFY_OUTF_ALL	3  /* both rpm and diff */
 
 #define INL_ATT_SIZE (sizeof(char*) + sizeof(int) + sizeof(int))
 
+#define SHA1_ASCII_LEN          40
+#define MD5_ASCII_LEN           32
+
+#define INL_BF_NAME		(1 << 0)
+#define INL_BF_LINKNAME		(1 << 1)
+#define INL_BF_SIZE		(1 << 2)
+#define INL_BF_PERMISSIONS	(1 << 3)
+#define INL_BF_OWNERS		(1 << 4)
+#define INL_BF_MDATE		(1 << 5)
+#define INL_BF_MD5		(1 << 6)
+#define INL_BF_SHA1		(1 << 7)
+#define INL_BF_SHA512		(1 << 8)
+
 #define INL_NAME_OFFSET			0
 #define INL_LINKNAME_OFFSET		((int)((char*)(&(AA.linknameM)) - ((char*)(&AA))))
 #define INL_SIZE_OFFSET 		((int)((char*)(&(AA.sizeM)) - ((char*)(&AA))))
@@ -61,9 +77,36 @@
 #define INL_STATUS_1_1_NEQ	0	/*  (worst) present in INFO and system and unequal */
 #define INL_STATUS_MISSING_FILE -1	/* even worst */
 
+#define RPMV_RESULT_STRING_LEN	8
+#define RPMV_STATUS_STRING	"SM5DLUGTP"
+#define RPMV_FORMAT_LEN	(RPMV_RESULT_STRING_LEN+3)   /* ``SM5DLUGTP X '' */
+
+#define RPMV_fail_size		'S'
+#define RPMV_fail_mode		'M'
+#define RPMV_fail_digest	'5'
+#define RPMV_fail_device	'D'
+#define RPMV_fail_linkname	'L'
+#define RPMV_fail_user		'U'
+#define RPMV_fail_group		'G'
+#define RPMV_fail_mtime		'T'
+#define RPMV_fail_cap		'P'
+#define RPMV_fail_NOT		'.'
+#define RPMV_fail_unknown	'?'
+#define RPMV_fail_fail		'X'  /* used as catch-all value for failed, never displayed to user */
+#define RPMV_fail_MISSING	'x'  /* used as catch-all value for failed, never displayed to user */
+
+#define RPMV_offset_size	0
+#define RPMV_offset_mode	1	
+#define RPMV_offset_digest	2	
+#define RPMV_offset_device	3	
+#define RPMV_offset_linkname	4	
+#define RPMV_offset_user	5	
+#define RPMV_offset_group	6	
+#define RPMV_offset_mtime	7	
+
 typedef struct {
-	char * addrM;
-	int lenM;
+	char * addrM;   /* C-address within line */
+	int lenM;       /* length of data */
 	int statusM;
 } INFOITEM;
 
@@ -77,6 +120,8 @@ typedef struct {
 	INFOITEM md5M;
 	INFOITEM sha1M;
 	INFOITEM sha512M;
+	STROB * rpmvM;  /* RPM-like verification string */
+	char * lineM;	/* address of original line */
 } INFOLINE;
 
 
@@ -99,4 +144,6 @@ int swverify_ls_fileset_from_iscat(SWI * swi);
 int swverify_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol, SWICAT_SC * sc, SWICAT_SR * sr,
 			int ofd, int ifd, int *, SWUTS * uts, char * pax_write_command_key, int *);
 
+char * swverify_v_looper_prelink_md5_func(STROB * buf);
+
 #endif
