@@ -828,7 +828,7 @@ class swExStruct_i: public swExStruct
 			// Prepend "catalog"
 			//
 			memmove(p+8, p, strlen(p)+1);
-			memcpy(p, SW_CATALOG "/", 8);
+			memcpy(p, SW_A_catalog "/", 8);
 		}
 	}
 
