@@ -464,7 +464,7 @@ public:
 		int filesize;
 		char * name;
 
-		nullfd = SWBIS_NULL_FD;
+		nullfd = UXFIO_NULL_FD;
 		name = swfile_get_package_filename();	
 		source_fd = swfile_open_public_image_fd();
 		
