@@ -649,6 +649,7 @@ public: // =====================================================================
 	//
 	// 5.2.13.5 Exclude Files
 	//
+
 	int
 	processExcludes(swDefinitionFile* psf, char * value) {
 		int i;
@@ -664,9 +665,12 @@ public: // =====================================================================
 		int t_dflag;
 		int l_dflag;
 		int does_have_trailing_slash;
+		int num_of_trailing_slash;
 		int first_match;
+		int ret;
 		char * type;
 
+		num_of_trailing_slash = 0;
 		does_have_trailing_slash = 0;
 		is_dir = 0;
 		t_dflag = 0;
@@ -677,8 +681,6 @@ public: // =====================================================================
 		excl_pat = strob_open(100);
 		pat_list = strar_open();
 
-
-	
 		SWEXTDEF_DEBUG2("value is [%s]", value);
 
 		//
@@ -694,20 +696,35 @@ public: // =====================================================================
 		//
 		// Apply a special case of trailing slash, DIR/, which is treated as DIR/*
 		//
-		if (source && strlen(source) && source[strlen(source)-1] == '/') {
+
+		//
+		// Detect and remove trailing slashes
+		//
+		if (source && strlen(source)) {
+			swlib_toggle_all_trailing_slash("drop", source, &num_of_trailing_slash);
+		}
+
+		SWEXTDEF_DEBUG2("num_of_trailing_slash = [%d]", num_of_trailing_slash);
+		if (num_of_trailing_slash == 1) {
+			//
+			// One trailing slash means the same thing as *NO* trailing slash
 			//
 			// we will treat this as a pattern to exclude the 
 			// entire directory contents and the directory entry itself
+			// It does this by adding a second globbing pattern.
 			//
+			// NOTE that if num_of_trailing_slash > 1, then this is
+			// not done because this is assinged a special meaning
+			// to exclude the directory entry alone.
+			//
+			SWEXTDEF_DEBUG("does have trailing slash");
 			does_have_trailing_slash = 1;
-		} else {
-			//
-			// do not augment with .../* to exclude contents
-			// if indeed the source is a directory
-			//
-			;
 		}
 
+		//  
+		//  num_of_trailing_slash >=2 has special meaning and means
+		//  exclude the directory but not its contents
+
 		//
 		// Now form the pattern
 		//
@@ -724,6 +741,7 @@ public: // =====================================================================
 			//
 			char * t;
 
+			SWEXTDEF_DEBUG("directoryDestActive and /");
 			t = strstr(source, strob_str(directory_pathM));
 			if (t) {
 				t += strob_strlen(directory_pathM);
@@ -738,6 +756,17 @@ public: // =====================================================================
 		SWEXTDEF_DEBUG3("concatenating [%s] [%s]", strob_str(excl_pat), strob_str(f_source));
 		strob_strcpy(excl_pat, strob_str(directory_sourceM));
 		swlib_unix_dircat(excl_pat, strob_str(f_source));
+
+		if (num_of_trailing_slash == 1) {
+			//
+			// Trailing slashes were removed above
+			// put back the correct number
+			//
+			strob_strcat(excl_pat, "/");
+		}
+
+		SWEXTDEF_DEBUG2("excl_pat is now [%s]", strob_str(excl_pat));
+
 		swlib_toggle_trailing_slashdot("drop", strob_str(excl_pat), &t_dflag);
 		swlib_toggle_leading_dotslash("drop", strob_str(excl_pat), &l_dflag);
 		
@@ -761,6 +790,7 @@ public: // =====================================================================
 				return -1;
 			}
 
+			SWEXTDEF_DEBUG2("def_source [%s]", def_source);
 			//
 			// Strip off absolute part if directory_sourceM is relative.
 			//
@@ -771,8 +801,13 @@ public: // =====================================================================
 			}
 
 			SWEXTDEF_DEBUG3("comparing for exclusion : fnmatch [%s] [%s]", strob_str(excl_pat), mdef_source);
-			// if (fnmatch(strob_str(excl_pat), mdef_source, 0) == 0) {
-			if (process_fnmatch_list(pat_list, mdef_source) == 0) {
+		
+			//
+			// Process the pattern list through fnmatch
+			//
+			ret = process_fnmatch_list(pat_list, mdef_source);
+
+			if (ret == 0) {
 				//
 				// Got match
 				//
@@ -785,15 +820,41 @@ public: // =====================================================================
 					fprintf(stderr,"swpackage: error: type attribute not found in processExcludes().\n");
 					return -1;
 				}
-				if (first_match == 0 && *type == 'd' && (directoryDestActive()==0 || does_have_trailing_slash)) {
+				if (
+					first_match == 0 && 
+					*type == 'd' && 
+					num_of_trailing_slash <= 1 &&
+					(directoryDestActive()==0 || does_have_trailing_slash == 1)
+				) {
+					//
+					// Add trailing "/*"
+					// as a second pattern in order to match the directory contents
+					//
 					SWEXTDEF_DEBUG2("ADDING /* to pattern list, now [%s]", strob_str(excl_pat));
 					swlib_unix_dircat(excl_pat, "/*");
 					strar_add(pat_list, strob_str(excl_pat));
-				}
-				if (first_match == 0)
 					first_match = 1;
+				}
+
+				//
+				//  swdeffile_list_del(--i) shortens the list, hence we need to
+				//  decrement the index to get the next item on the list
+				//
+				//  Delete the entry because it matched
+				//
 				psf->swdeffile_list_del(--i);
+			} else if (ret < 0) {
+				//
+				// error
+				// FIXME
+				fprintf(stderr, "swpackage: exclude keyword: fnmatch error: ''%s''\n",
+						swlib_printable_safe_ascii(strar_get(pat_list, 0)));
+				return -1
+				;
 			} else {
+				//
+				// No Match
+				//
 				;
 				SWEXTDEF_DEBUG3("fnmatch result: NO MATCH [%s] [%s]", strob_str(excl_pat), mdef_source);
 			}
@@ -894,18 +955,20 @@ private: // ================================================================
 	 // ================================================================
 	 // ================================================================
 
+	// Private
 	int
 	process_fnmatch_list(STRAR * pat_list, char * mdef_source) {
 		int i;
 		char * pat;
 		int ret;
 
-		SWEXTDEF_DEBUG2("mdef_source is [%s]", mdef_source);
+		SWEXTDEF_DEBUG2("BEGIN mdef_source is [%s]", mdef_source);
 		ret = 1;
 		i = 0;
 		pat = strar_get(pat_list, i++);
 		while(pat && ret) {
-			SWEXTDEF_DEBUG3("pat[%d] is [%s]", i-1, pat);
+			SWEXTDEF_DEBUG3("LOOP pat[%d] is [%s]", i-1, pat);
+			SWEXTDEF_DEBUG2("mdef_source = [%s]", mdef_source);
 			//
 			// Check for the case
 			//   where pat=/dir/A/B/C/  and mdef_source=/dir/A/B/C
@@ -913,16 +976,23 @@ private: // ================================================================
 			// (fnmatch wil not).   This is used to exlude a single
 			// directory with out excluding the contents of /dir/A/B/C
 			//
-			if (	pat &&
+			
+			SWEXTDEF_DEBUG3("mdef_source  :  pat  [%s] [%s]", mdef_source, pat);
+			SWEXTDEF_DEBUG3("strlen(mdef_source) == strlen(pat)-1  [%d] [%d]", (int)strlen(mdef_source), (int)(strlen(pat)-1));
+			if (
+				pat &&
 				strlen(pat) > 1 &&
 				*(pat+strlen(pat)-1) == '/' &&
 				strlen(mdef_source) == strlen(pat)-1 &&
 				strpbrk(pat, "*?") == NULL &&
 				strncmp(pat, mdef_source, strlen(pat)-1) == 0
 			) {
+				//
 				// Got a match for the special case to exlude
 				// a directory but not its contents
-				SWEXTDEF_DEBUG("Got special match 0001");
+				//
+				SWEXTDEF_DEBUG("\nGot special match 0001\n");
+				SWEXTDEF_DEBUG("BREAK 1");
 				ret = 0;
 				break;
 			}
@@ -939,14 +1009,32 @@ private: // ================================================================
 				break;	
 			}
 
-			SWEXTDEF_DEBUG3("---- fnmatch(%s, %s)", pat, mdef_source);
+			SWEXTDEF_DEBUG3("CALLING ---- fnmatch(%s, %s)", pat, mdef_source);
 			ret = fnmatch(pat, mdef_source, 0);
-			if (ret == 0) break;
+			if (ret == 0) {
+				//
+				// match
+				//
+				SWEXTDEF_DEBUG3("        ---- fnmatch(%s, %s) MATCH", pat, mdef_source);
+			       	break;
+			} else if (ret == FNM_NOMATCH) {
+				//
+				// no match
+				//
+				SWEXTDEF_DEBUG3("        ---- fnmatch(%s, %s) NO MATCH", pat, mdef_source);
+			} else {
+				//
+				// error
+				// FIXME
+				return -1;
+				;
+			}
 			pat = strar_get(pat_list, i++);
 		}
 		return ret;
 	}
 
+
 	int
 	pattern_is_wild(char * p) {
 		if (strpbrk(p, "?*[")) return 1;
