@@ -63,7 +63,7 @@ swDefinition * swPSF::makeDefinition (char * parser_line, int * retval) {
 	swdef=swDefinition::swdefinition_factory(parser_line);
 	
 	if (swdef == static_cast<swDefinition*>(NULL)) {
-		fprintf(stderr, "internal error\n");
+		fprintf(stderr, "internal error in swPSF::makeDefinition 002\n");
 		assert(NULL);
 		return NULL;
 	}
