@@ -84,6 +84,11 @@ public:
 		swextM->set_digests2_creation(s);
 	}
 
+	void
+	set_follow_symlinks(int s) {
+		swextM->set_follow_symlinks(s);
+	}
+
 	virtual int get_type(void) { return swstructdef::return_entry_index(NULL, "PSF"); }
       
 	virtual swMetaData * generate_attribute_list (int at_level, int * retvalp);
