@@ -80,19 +80,6 @@
 #define OLDFRMT		"%b %e  %Y"
 #define NAME_WIDTH	8
 
-/*
-#define PAX_DIR         1                * directory *
-#define PAX_CHR         2                * character device *
-#define PAX_BLK         3                * block device *
-#define PAX_REG         4                * regular file *
-#define PAX_SLK         5                * symbolic link *
-#define PAX_SCK         6                * socket *
-#define PAX_FIF         7                * fifo *
-#define PAX_HLK         8                * hard link *
-#define PAX_HRG         9                * hard link to a regular file *
-#define PAX_CTG         10               * high performance file *
-*/
-
 #define PAX_DIR        DIRTYPE
 #define PAX_CHR        CHRTYPE
 #define PAX_BLK        BLKTYPE     
@@ -150,12 +137,19 @@ char *
 prepend_dotslash(char *str, STROB * fp)
 {
     if (strcmp(str, ".") == 0) {
+	/* . alone */
+	E_DEBUG();
        return "./";
     } else if (strncmp(str, "./", 2) == 0) {
+	E_DEBUG();
+	/* leading ./  do nothing */
        return str;
-    } else if (strcmp(str, "/") == 0) {
+    } else if (strncmp(str, "/", 1) == 0) {
+	/* / alone or not, prepend . */
+	E_DEBUG();
        strob_strcat(fp, ".");
     } else {
+	E_DEBUG();
        strob_strcat(fp, "./");
     }
     return str;
@@ -247,6 +241,11 @@ ls_list_safe_print_to_strob(char *fp_str, STROB * fp, int do_prepend)
   char *cp;
   char * str;
 
+/*
+fprintf(stderr, "JLJLx Before\n");
+fprintf(stderr, "JLJLx Before\n");
+fprintf(stderr, "JLJLx Before string <%s>\n", fp_str);
+*/
   if (do_prepend) {
 	str = prepend_dotslash(fp_str, fp);
   } else {
@@ -267,6 +266,12 @@ ls_list_safe_print_to_strob(char *fp_str, STROB * fp, int do_prepend)
     {
       strob_strcat(fp, str);
     }
+/*
+fprintf(stderr, "JLJLx Final string <%s>\n", strob_str(fp));
+fprintf(stderr, "JLJLx Final string\n");
+fprintf(stderr, "JLJLx Final string\n");
+*/
+
 }
 
 
@@ -417,17 +422,21 @@ do_print_ids:
 
 static
 void
-print_linkname(STROB * fp, int type, char * ln_name)
+print_linkname(STROB * fp, int type, char * ln_name, int do_prepend)
 {
 	if ((type == PAX_HLK) || (type == PAX_HRG)) {
 		/* strob_strcat(fp, " == "); */
 		strob_strcat(fp, " link to ");
-		ls_list_safe_print_to_strob(ln_name, fp, 0);
+		ls_list_safe_print_to_strob(ln_name, fp, do_prepend);
 	} else {
 		if (type == PAX_SLK) {
 			strob_strcat(fp, " -> ");
-			ls_list_safe_print_to_strob(ln_name, fp, 0);
-    		}
+			ls_list_safe_print_to_strob(ln_name, fp, do_prepend);
+    		} else {
+			/* print no symbol indicating a link, just the name */
+			strob_strcat(fp, "");
+			ls_list_safe_print_to_strob(ln_name, fp, do_prepend);
+		}
 	}
 }
 
@@ -503,7 +512,7 @@ alt_ls_list_to_string(char * fp_name, char * ln_name, struct new_cpio_header * f
 	name_len = strob_strlen(fp);
 
 	strob_strcpy(fp, "");
-	print_linkname(fp, type, ln_name);
+	print_linkname(fp, (LS_LIST_VERBOSE_LINKNAME_PLAIN & vflag) ? 0 : type, ln_name, vflag & LS_LIST_VERBOSE_PREPEND_DOTSLASH);
 	linkname_len = strob_strlen(fp);
 
 	/* print the name length */
@@ -514,7 +523,7 @@ alt_ls_list_to_string(char * fp_name, char * ln_name, struct new_cpio_header * f
 
 	/* print the linkname */
 	strob_sprintf(fp, 1 /* do append */, " [" LS_LIST_LINKNAME_LENGTH "=%d " LS_LIST_LINKNAME_MARK, linkname_len);
-	print_linkname(fp, type, ln_name);
+	print_linkname(fp,  (LS_LIST_VERBOSE_LINKNAME_PLAIN & vflag) ? 0 : type, ln_name, vflag & LS_LIST_VERBOSE_PREPEND_DOTSLASH);
 	strob_strcat(fp, "]]");
 	
 	/* filesize */
@@ -614,7 +623,7 @@ ls_list_to_string(char * fp_name, char * ln_name, struct new_cpio_header * file_
 	ls_list_safe_print_to_strob(name, fp, vflag & LS_LIST_VERBOSE_PREPEND_DOTSLASH);
 
 	/* Print the linkname for symlinks and hard links */
-	print_linkname(fp, type, ln_name);
+	print_linkname(fp, (LS_LIST_VERBOSE_LINKNAME_PLAIN & vflag) ? 0 : type, ln_name, vflag & LS_LIST_VERBOSE_PREPEND_DOTSLASH);
 
 	return;
 }
