@@ -203,7 +203,7 @@ internal_redirect(
 
 static
 SHCMD* 
-shcmd_common_open(char * cmdstring)
+shcmd_common_open(/* char * cmdstring */ void)
 {
 	mode_t mode = (mode_t)0;
 	int i;
@@ -527,12 +527,10 @@ int
 shcmd_cmdvec_wait2(SHCMD ** cmd_vec)
 {
 	SHCMD ** cmdv = cmd_vec;
-	pid_t pid;
 	int ncmds = 0;
 	int ncmds_exited = 0;
 	int i;
 	int ret;
-	int error_mode = 0;
 	int highest_index_with_error;
 	
 	while(*cmdv) {
@@ -668,7 +666,7 @@ shcmd_do_tainted_data_check(char * cmdstring)
 SHCMD *
 shcmd_open(void)
 {
-	return shcmd_common_open((char*)NULL);
+	return shcmd_common_open(/*(char*)NULL*/);
 }
 
 int 
@@ -717,28 +715,38 @@ shcmd_debug_show_to_file(SHCMD *cmd, FILE * file)
 }
 
 int
-shcmd_debug_show_command(SHCMD *cmd, int fd)
+shcmd_write_command_to_buf(SHCMD *cmd, STROB * tmp)
 {
-	STROB * tmp = strob_open(10);
 	char **arg = cmd->argv_;
 	if (arg) {
 		while(*arg) {
 			if (strpbrk(*arg, "; &*?$|<>`\"")) {
-				swlib_writef(fd, tmp, "'%s'",  *arg);
+				strob_sprintf(tmp, STROB_DO_APPEND, "'%s'",  *arg);
 			} else if (strlen(*arg) == 0) {
-				swlib_writef(fd, tmp, "''");
+				strob_sprintf(tmp, STROB_DO_APPEND, "''");
 			} else {
-				swlib_writef(fd, tmp, "%s",  *arg);
+				strob_sprintf(tmp, STROB_DO_APPEND, "%s",  *arg);
 			}
 			arg++;
-			if (*arg) swlib_writef(fd, tmp, " ");
+			if (*arg) strob_sprintf(tmp, STROB_DO_APPEND," ");
 		}
-		swlib_writef(fd, tmp, "\n");
 	} 
-	strob_close(tmp);
 	return 0;
 }
 
+int
+shcmd_debug_show_command(SHCMD *cmd, int fd)
+{
+	int ret;
+	STROB * tmp = strob_open(10);
+	shcmd_write_command_to_buf(cmd, tmp);
+	strob_sprintf(tmp, STROB_DO_APPEND, "\n");
+	ret = uxfio_write(fd, strob_str(tmp), strob_strlen(tmp));
+	strob_close(tmp);
+	return ret;
+}
+
+
 void
 shcmd_close(SHCMD * shcmd)
 {
