@@ -182,3 +182,10 @@ strar_qsort_strcmp(const void * vf1, const void * vf2)
 {
 	return f_strcmp(1, vf1, vf2);
 }
+
+void
+strar_remove_index(STRAR * strar, int index)
+{
+	cplob_remove_index(strar->listM, index);
+	strar->nsM--;
+}
