@@ -125,7 +125,8 @@ add_path_code(STROB * buf)
 	 */
 	strob_sprintf(buf, STROB_DO_APPEND,
 	CSHID
-	"gpath=`getconf PATH`\n"
+	"export SWPATH\n"
+	"gpath=$(getconf PATH)\n"
 	"case \"$gpath\" in\n"
 	"	\"\")\n"
 	"		SWPATH=\"$PATH\"\n"
@@ -447,7 +448,7 @@ form_absolute_control_dir(STROB * tmp, SWI * swi, char * control_script_pkg_dir,
 	swlib_squash_trailing_slash(strob_str(tmp));
 	swlib_squash_double_slash(strob_str(tmp));
 	if (swlib_check_clean_absolute_path(strob_str(tmp)))
-		SWLIB_FATAL("internal error");
+		SWLIB_FATAL("internal error: form_absolute_control_dir-1");
 
 	/*
 	 * Now take the dirname of this.
@@ -458,7 +459,7 @@ form_absolute_control_dir(STROB * tmp, SWI * swi, char * control_script_pkg_dir,
 		s++;
 		*script_name = s;
 	} else {
-		SWLIB_FATAL("internal error");
+		SWLIB_FATAL("internal error: form_absolute_control_dir-2");
 	}
 	return;
 }
@@ -751,13 +752,7 @@ swicat_env(STROB * buf, SWI * swi, char * control_script_pkg_dir, char * tag)
 		add_env_entry("SW_ROOT_DIRECTORY", "/", buf);
 	}
 
-	/*
-	 * SW_CATALOG same as installed_software.catalog and may be
-	 * a relative path
-	 */
-	add_env_entry("SW_CATALOG", swi->swi_pkgM->installed_software_catalogM, buf);
-
-	add_env_entry("SW_PATH", "\"$PATH\"", buf);
+	add_env_entry("SW_PATH", "$PATH", buf);
 
 	/*
 	 * SWBIS_CATALOG_ENTRY is what is after the <installed_software_catalog> path
@@ -773,6 +768,20 @@ swicat_env(STROB * buf, SWI * swi, char * control_script_pkg_dir, char * tag)
 
 	add_env_entry("SWBIS_CATALOG_ENTRY", tmp_s, buf);
 
+	/*
+	 * Wrong.. SW_CATALOG same as installed_software.catalog and is a 
+	 * Wrong.. a relative path (It is not the installed_software_catalog option value)
+	 */
+	/* Actually, SW_CATALOG is really the path such as, for example:
+
+		 var/lib/swbis/catalog/foo/foo/1.1/0/
+
+	   prior to version 1.12, the value of SW_CATALOG was set by the following line:
+		add_env_entry("SW_CATALOG", swi->swi_pkgM->installed_software_catalogM, buf);
+	*/
+
+	add_env_entry("SW_CATALOG", swi->swi_pkgM->catalog_entryM, buf);
+
 	SWLIB_ASSERT(swi->swi_pkgM->locationM != NULL);
 	add_env_entry("SW_LOCATION", swi->swi_pkgM->locationM, buf);
 	
@@ -781,11 +790,9 @@ swicat_env(STROB * buf, SWI * swi, char * control_script_pkg_dir, char * tag)
 	if (*(swi->swi_pkgM->installed_software_catalogM) == '/') {
 		/* The installed_software_catalog was specified as 
 		   an absolute path */
-		add_env_entry("SW_SESSION_OPTIONS",
-			"${SW_CATALOG}/${SWBIS_CATALOG_ENTRY}/" SW_A_session_options , buf);
+		add_env_entry("SW_SESSION_OPTIONS", "${SW_CATALOG}/" SW_A_session_options , buf);
 	} else {
-		add_env_entry("SW_SESSION_OPTIONS",
-			"${SW_ROOT_DIRECTORY}/${SW_CATALOG}/${SWBIS_CATALOG_ENTRY}/" SW_A_session_options , buf);
+		add_env_entry("SW_SESSION_OPTIONS", "${SW_ROOT_DIRECTORY}/${SW_CATALOG}/" SW_A_session_options , buf);
 	}
 
 
@@ -884,7 +891,7 @@ swicat_write_script_cases(SWI * swi, STROB * buf, char * sw_selection)
 
 	tmp = strob_open(32);
 	/*
-	 * the first step is too find the object implied by
+	 * the first step is to find the object implied by
 	 * sw_selection.  sw_selection has the form:
 	 *     <prod_tag>.<fileset_tag>
 	 */
@@ -908,6 +915,10 @@ swicat_write_script_cases(SWI * swi, STROB * buf, char * sw_selection)
 	product_tag = cplob_val(taglist, 0);
 	fileset_tag = cplob_val(taglist, 1);  /* may be NUL */
 
+	/* FIXME
+	 * Assumes one fileset
+	 */
+
 	product = swi_find_product_by_swsel(swi->swi_pkgM, product_tag, NULL, (int*)NULL);
 	SWLIB_ASSERT(product != NULL);   /* fatal */
 
@@ -946,7 +957,7 @@ swicat_write_script_cases(SWI * swi, STROB * buf, char * sw_selection)
 	
 	add_env_entry("SW_SOFTWARE_SPEC", strob_str(tmp), buf);
 	
-	ret = swi_afile_write_script_cases(scripts,  buf);
+	ret = swi_afile_write_script_cases(scripts,  buf, swi->swi_pkgM->installed_software_catalogM);
 	ret = 0;
 	SWLIB_ASSERT(ret == 0);   /* fatal */
 
@@ -1074,6 +1085,7 @@ swicat_write_isc_script(STROB * script_buf,
 	"	0)\n"
 	);
 
+	E_DEBUG("");
 	strob_sprintf(script_buf, 1, 
 			"sw_retval=0\n"
 			"(\n"		/* subshell */
@@ -1097,8 +1109,10 @@ swicat_write_isc_script(STROB * script_buf,
 
 	if (swspecs) {
 		/* write listing or query blob */
+		E_DEBUG("");
 		if (vplob_get_nstore(swspecs) <= 0) {
 			/* add a "*" spec */
+			E_DEBUG("");
 			swverid = swverid_open(NULL, "*");
 			if (swverid == NULL) {
 				return -1;
@@ -1107,7 +1121,9 @@ swicat_write_isc_script(STROB * script_buf,
 			}
 		}
 
+		E_DEBUG("Looping over swspecs");
 		while ((swverid=vplob_val(swspecs, i++)) != NULL) {
+			E_DEBUG2("in swpec number [%d]", i);
 			write_query_blob(G, swverid, script_buf, tmp, -1, NULL);
 	
 			/* Here is the command that reads the shell variables */
@@ -1115,37 +1131,62 @@ swicat_write_isc_script(STROB * script_buf,
 				"shls_get_verid_list | shls_apply_socspec\n"
 				"\n");
 		}
-	} else {
+	} else if (swspecs_pre || swspecs_co || swspecs_ex) {
 		/* write requisite checks blobs */
+		E_DEBUG("");
 		query_num = 0;
 		i = 0;
-		if (swspecs_pre)
-		while ((swverid=vplob_val(swspecs_pre, i++)) != NULL) {
-			write_query_blob(G, swverid, script_buf, tmp, query_num, SWICAT_REQ_TYPE_P);
-			strob_sprintf(script_buf, 1, "shls_get_verid_list | shls_apply_socspec\n" "\n");
-			query_num++;
+		if (swspecs_pre) {
+			E_DEBUG("have swspecs_pre");
+			while ((swverid=vplob_val(swspecs_pre, i++)) != NULL) {
+				E_DEBUG2("in swpec number [%d]", i);
+				write_query_blob(G, swverid, script_buf, tmp, query_num, SWICAT_REQ_TYPE_P);
+				strob_sprintf(script_buf, 1, "shls_get_verid_list | shls_apply_socspec\n" "\n");
+				query_num++;
+			}
 		}
+		i=0;
+		if (swspecs_co) {
+			E_DEBUG("have swspecs_co");
+			while ((swverid=vplob_val(swspecs_co, i++)) != NULL) {
+				E_DEBUG2("in swpec number [%d]", i);
+				write_query_blob(G, swverid, script_buf, tmp, query_num, SWICAT_REQ_TYPE_C);
+				strob_sprintf(script_buf, 1, "shls_get_verid_list | shls_apply_socspec\n" "\n");
+				query_num++;
+			}
+		}	
+		i=0;
+		if (swspecs_ex) {
+			E_DEBUG("have swspecs_ex");
+			while ((swverid=vplob_val(swspecs_ex, i++)) != NULL) {
+				E_DEBUG2("in swpec number [%d]", i);
+				write_query_blob(G, swverid, script_buf, tmp, query_num, SWICAT_REQ_TYPE_E);
+				strob_sprintf(script_buf, 1, "shls_get_verid_list | shls_apply_socspec\n" "\n");
+				query_num++;
+			}
+		}
+		if (query_num == 0) {
+			E_DEBUG("have no blobs whatsoever");
+			/* here NO query blobs were written, which means we owe the script syntax
+				a command (symmetric with 
+					shls_get_verid_list | shls_apply_socspec
 
-		i=0;
-		if (swspecs_co)
-		while ((swverid=vplob_val(swspecs_co, i++)) != NULL) {
-			write_query_blob(G, swverid, script_buf, tmp, query_num, SWICAT_REQ_TYPE_C);
-			strob_sprintf(script_buf, 1, "shls_get_verid_list | shls_apply_socspec\n" "\n");
-			query_num++;
-		}
-		
-		i=0;
-		if (swspecs_ex)
-		while ((swverid=vplob_val(swspecs_ex, i++)) != NULL) {
-			write_query_blob(G, swverid, script_buf, tmp, query_num, SWICAT_REQ_TYPE_E);
-			strob_sprintf(script_buf, 1, "shls_get_verid_list | shls_apply_socspec\n" "\n");
-			query_num++;
+				Use dd if=/dev/null 2>/dev/null
+			*/
+			strob_sprintf(script_buf, 1, "dd if=/dev/null 2>/dev/null\n");
 		}
+	} else {
+		/* This should never happen */
+		sw_e_msg(G, "internal error in swicat_write_isc_script()\n");
+		;
+		E_DEBUG("");
+
 	}
 
 	/* echo TRAILER!!! as a terminator so that a reading process on the
 	   management host knows when to stop reading. */
 
+	E_DEBUG("");
 	if (strcmp(list_vform, SWICAT_FORM_TAR1) == 0) {
 		strob_sprintf(script_buf, 1,
 			")\n"
