@@ -90,7 +90,7 @@ void swicat_write_auto_comment(STROB * buf, char * filename);
 int swicat_write_script_cases(SWI * swi, STROB * buf, char * sw_selection);
 void swicat_construct_controlsh_taglist(SWI * swi, char * sw_selections, STROB * list);
 int swicat_r_get_installed_catalog(GB * G, VPLOB * swspecs, char * target_path);
-int swicat_write_isc_script(STROB * script_buf, GB * G, VPLOB * swspecs, VPLOB *,VPLOB *,VPLOB *, char * target_path, char * lform);
+int swicat_write_isc_script(STROB * script_buf, GB * G, VPLOB * swspecs, VPLOB *,VPLOB *,VPLOB *, char * lform);
 int swicat_req_analyze(GB * G, SWICAT_REQ *, char * query_result, SWICAT_SL **);
 SWICAT_REQ * swicat_req_create(void);
 void swicat_req_delete(SWICAT_REQ *);
