@@ -814,6 +814,27 @@ swlib_i_pipe_pump(int suction_fd, int discharge_fd,
 	return -1;
 }
 
+char *
+swlib_printable_safe_ascii(char * sf) {
+	char * s;
+	/*
+	 * Now check if all char are ascii
+	 */
+	s = sf;
+
+	while (s && *s) {
+		if (*s > 126 || *s < 33) {
+			/*
+			 * For now, just set the byte
+			 * to a single '.'
+			 */
+			*s = '.';
+		}
+		s++;
+	}
+	return sf;
+}
+
 int
 swlib_is_ascii_noaccept(char * str, char * acc, int minlen) {
 	unsigned char *s;
@@ -1140,6 +1161,19 @@ swlib_toggle_trailing_slash(char * mode, char * name, int *pflag)
 	}
 }
 
+void
+swlib_toggle_all_trailing_slash(char * mode, char * name, int *pflag)
+{
+	int pf = 0;
+	*pflag = 0;
+	swlib_toggle_trailing_slash(mode, name, &pf);
+	while (pf) {
+		(*pflag) ++;
+		pf = 0;
+		swlib_toggle_trailing_slash(mode, name, &pf);
+	}
+}
+
 void
 swlib_squash_leading_slash(char * name)
 {
