@@ -32,7 +32,6 @@
 
 #include "debug_config.h"
 
-#define SWVARFSNEEDDEBUG 1
 #undef SWVARFSNEEDDEBUG
 
 #ifdef SWVARFSNEEDDEBUG
@@ -515,6 +514,7 @@ set_linkname(SWVARFS * swvarfs, int ufd, char * path)
 	struct new_cpio_header * file_hdr;
 	char * s;
 	char * vlinkp;
+	int vlen = 1024;  /* FIXME arbitrary limit */
 
 	SWVARFS_E_DEBUG2("ENTERING [%s]", path); 
 	if (ufd < 0) {
@@ -533,20 +533,20 @@ set_linkname(SWVARFS * swvarfs, int ufd, char * path)
 	}
 	file_hdr = ahs_vfile_hdr(swvarfs->ahsM);
 
-	ahsStaticSetTarLinknameLength(file_hdr, 200);
+	ahsStaticSetTarLinknameLength(file_hdr, vlen);
 	s = ahsStaticGetTarLinkname(file_hdr);
-	s[199] = '\0';	
-	c=readlink(path, s, 199);
+	s[vlen-1] = '\0';	
+	c=readlink(path, s, vlen-1);
 	if (c < 0) {
 	SWBIS_E_FAIL3("error: readlink on [%s] returned %d.\n", path, c);
 		return -1;
 	}
-	if (c >= 199) {
-		c = 199;
+	if (c >= vlen-1) {
+		c = vlen -1;
 		fprintf(stderr, "Warning, linkname [%s] truncated.\n", s);
 	}
 	s[c] = '\0';	
-	if (strlen(s) > 99) {
+	if (strlen(s) > TARNAMESIZE) {
 		fprintf(stderr, 
 		"Warning, linkname [%s] is too long for tar archives\n", s);
 	}
@@ -701,7 +701,7 @@ stat_node(SWVARFS * swvarfs, char * fp_path, struct stat * statbuf)
 	if (S_ISLNK(statbuf->st_mode)) {
 		set_linkname(swvarfs, -1, fp_path);
 	} else {
-		ahsStaticSetTarLinkname(ahs_vfile_hdr(swvarfs->ahsM), NULL);
+		ahsStaticSetPaxLinkname(ahs_vfile_hdr(swvarfs->ahsM), NULL);
 	}
 	SWVARFS_E_DEBUG("END"); 
 	return 0;
@@ -1053,8 +1053,8 @@ swvarfs_i_u_open_fs(SWVARFS * swvarfs, char * name)
 		set_linkname(swvarfs, fd, strob_str(swvarfs->u_nameM));
 	}
 	taru_statbuf2filehdr(ahs_vfile_hdr(swvarfs->ahsM), &st, NULL,
-			ahsStaticGetTarFilename(ahs_vfile_hdr(swvarfs->ahsM)), 
-			ahsStaticGetTarLinkname(ahs_vfile_hdr(swvarfs->ahsM)));
+			/*ahsStaticGetTarFilename(ahs_vfile_hdr(swvarfs->ahsM))*/ strob_str(swvarfs->u_nameM), 
+			/*ahsStaticGetTarLinkname(ahs_vfile_hdr(swvarfs->ahsM))*/ NULL );
 	uxfio_ioctl(fd, UXFIO_IOCTL_SET_STATBUF, (void*)&st);
 	swvarfs->u_fdM = fd;
 	return fd;
@@ -1857,7 +1857,7 @@ swvarfs_open_serial_access_file_internal(SWVARFS *swvarfs,
 	*/
 	strob_strcpy(swvarfs->opencwdpathM, "");
 	strob_strcpy(swvarfs->dirscopeM, "");
-	swvarfs->fdM = uinfile_open(name, (mode_t)(NULL),
+	swvarfs->fdM = uinfile_open(name, (mode_t)(0),
 				&(swvarfs->format_descM), oflags);
 	swvarfs->did_dupM=1;
 	if (swvarfs->fdM < 0) {
@@ -2059,7 +2059,7 @@ swvarfs_u_readlink(SWVARFS * swvarfs, char * path, char * buf, size_t bufsize)
 	char * s;
 	int ret;
 
-	if (swvarfs->formatM !=UINFILE_FILESYSTEM) {
+	if (swvarfs && swvarfs->formatM !=UINFILE_FILESYSTEM) {
 		fd = swvarfs_u_open(swvarfs, path);
 		if (fd < 0) return -4;
 
@@ -2585,10 +2585,10 @@ swvarfs_get_next_dirent(SWVARFS * swvarfs, struct stat *st)
 		SWVARFS_E_DEBUG(""); 
 	} else {
 		int * peoa = &(swvarfs->eoaM);
-		SWVARFS_E_DEBUG(""); 
+		SWVARFS_E_DEBUG("entering swvarfs_get_next_dirent_archive_NEW"); 
 		name = swvarfs_get_next_dirent_archive_NEW(swvarfs, st, peoa);
 		is_at_end = *peoa;
-		SWVARFS_E_DEBUG(""); 
+		SWVARFS_E_DEBUG2("SWVARFS (ARCHIVE) EOA=[%d]", *peoa); 
 	}
 
 	SWVARFS_E_DEBUG(""); 
@@ -2617,10 +2617,11 @@ swvarfs_get_next_dirent(SWVARFS * swvarfs, struct stat *st)
 		/*
 		* end of archive.
 		*/
+		SWVARFS_E_DEBUG2("GOT EOA [%d]", is_at_end); 
 		name = NULL;
 		;
 	}
-	SWVARFS_E_DEBUG2("LEAVING %s", name?name:"<nil>"); 
+	SWVARFS_E_DEBUG2("LEAVING !!!!!!!!!!!!!!! [%s]", name?name:"<nil>"); 
 	return name;
 }
 
