@@ -38,6 +38,10 @@
 #define TOPSF_PSF_FORM2 	2
 #define TOPSF_PSF_FORM3 	3
 
+#define TOPSF_FILE_STATUS_UNSET		48 /* ascii 0 */
+#define TOPSF_FILE_STATUS_IN_HEADER	49 /* ascii 1 */
+#define TOPSF_FILE_STATUS_IN_ARCHIVE	50 /* ascii 2 */
+
 typedef struct {
 	char * prefix_;
 	char * cwd_prefix_;
@@ -51,7 +55,11 @@ typedef struct {
 	int fd_;	/* depricated */
 	int use_recursive_; /* Use "file *" to specify the fileset of a binary rpm */
 	int reverse_links_; /* Interpret hard links in reverse when converting to tar */
-	CPLOB  * archive_names_;  /* List of name in the rpm cpio archive */
+	STRAR * archive_namesM;  /* List of files in the rpm cpio archive */
+	STROB * file_status_arrayM; /* char Array: Status of appearance in cpio archive compared */
+				    /* compared to Header;  Index of array is analog to (RPM)Header index */
+				    /* 0=unset, 1 appear in one, 2 appears in both */
+	STRAR * header_namesM;    /* List of files from the Header */
 	int debug_link_;
 	int single_fileset_;
 	int info_only_;
@@ -67,6 +75,12 @@ typedef struct {
 	char * ownerM;
 	char * groupM;
 	STRAR * exclude_listM;
+	int rpm_construct_missing_filesM;  /* User option */
+	char * rpmtag_default_prefixM;  /* RPMTAG_DEFAULTPREFIX, use is very rare, */
+				        /* and deprecated but support it anyway */
+	STROB * usebuf1M;               /* pre-allocated buffer */
+					/* Set by the -v option of lxpsf program */
+	int verboseM;
 } TOPSF;
 
 TOPSF * topsf_open(char * filename, int oflags, char * package_name);
@@ -93,5 +107,7 @@ int 	topsf_write_info(TOPSF * topsf, int fd_out, int do_indent);
 int	topsf_h_write_to_buf(XFORMAT * xformat, char * name, STROB ** buf);
 int topsf_parse_slack_pkg_name(char * pkgfilename, STRAR * st);
 void topsf_add_excludes(TOPSF * topsf, STROB * buf);
+int topsf_check_header_list(TOPSF * topsf, STRAR * list, char * archive_name);
+int topsf_search_list(TOPSF * topsf, STRAR * list, char * archive_name);
 
 #endif
