@@ -13,6 +13,11 @@ esac
 
 . shell_lib.sh
 
+# This script requires a pre 2007-04-25 version of shell_lib.sh
+echo "This script requires a pre 2007-04-25 version of shell_lib.sh" 1>&2
+exit 1
+
+
 arg1="$1"
 remspec="$1"
 delim="$2"
@@ -21,9 +26,9 @@ do_stop=""
 c=0
 MAX_TOKENS=20
 
-id_cur_token "$remspec"
+shls_id_cur_token "$remspec"
 cursep="$gg_id_cur_sep"
-sh_brk_split "$remspec" "$cursep"
+shls_sh_brk_split "$remspec" "$cursep"
 curspec="$gg_ab_fir"
 remspec="$gg_ab_sec"
 gg_id_cur_token="SX_newspec"
@@ -45,7 +50,7 @@ do
 
 	case "$curtoken_type" in
 		SX_newspec)
-			swspec_init
+			shls_swspec_init
 			PARSED_SPEC="tag=$curspec"
 			;;
 		SX_tag)
@@ -60,10 +65,10 @@ do
 			echo "error: $curtoken_type" 1>&2
 			;;
 	esac
-	id_cur_token "$remspec"
+	shls_id_cur_token "$remspec"
 	curtoken_type="$gg_id_cur_token"
 	cursep="$gg_id_cur_sep"
-	sh_brk_split "$remspec" "$cursep"
+	shls_sh_brk_split "$remspec" "$cursep"
 	curspec="$gg_ab_fir"
 	remspec="$gg_ab_sec"
 	case "$do_stop" in yes) break; ;; esac
