@@ -124,7 +124,23 @@ lf_remove_lock() {
 }
 
 shls_check_for_gnu_tar() {
-	xxb_ver=`tar --version 2>&1 | grep GNU | head -1 | awk '{print $NF}';`
+	xxb_ver=`tar -H pax --version 2>&1 | grep GNU | head -1 | awk '{print $NF}';`
+	case "$xxb_ver" in
+		"") return 1; ;;
+		*) return 0; ;;
+	esac
+}
+
+shls_check_for_gnu_gtar() {
+	xxb_ver=`gtar -H pax --version 2>&1 | grep GNU | head -1 | awk '{print $NF}';`
+	case "$xxb_ver" in
+		"") return 1; ;;
+		*) return 0; ;;
+	esac
+}
+
+shls_check_for_recent_gnu_gtar() {
+	xxb_ver=`gtar -H pax --hard-dereference --version 2>&1 | grep GNU | head -1 | awk '{print $NF}';`
 	case "$xxb_ver" in
 		"") return 1; ;;
 		*) return 0; ;;
@@ -150,7 +166,7 @@ shls_write_cat_ar() {
 	xxcy_ret_tar=$?
 	xxcy_ret_pax=1
 	case "$xxcy_ret_tar" in
-		0) PAXCMD="tar  cf - -b1 --files-from=-";
+		0) PAXCMD="tar  cf - -H pax -b1 --files-from=-";
 		$PAXCMD
 		return "$?"
 		;;
@@ -196,7 +212,7 @@ shls_write_files_ar() {
 	case "$xxc_ret" in 0) PAXCMD="pax -d -b 512 -w"; ;; esac
 	shls_check_for_gnu_tar 0</dev/null
 	xxc_ret=$?
-	case "$xxc_ret" in 0) PAXCMD="tar cf - -b1 --no-recursion --files-from=-"; ;; esac
+	case "$xxc_ret" in 0) PAXCMD="tar cf - -H pax -b1 --no-recursion --files-from=-"; ;; esac
 	case "$PAXCMD" in
 		dd*)
 			dd of=/dev/null 2>/dev/null
@@ -2162,11 +2178,39 @@ shls_looper() {
 	return "$xr_sw_retval"
 }
 
+shls_v_looper() {
+	xvr_fname="$1"
+	shift
+	xvr_sw_retval="$1"
+	while test "$xvr_sw_retval" -eq 0 </dev/null
+	do
+		read line
+		case "$line" in
+			"TRAILER!!!")
+				break;
+				;;
+			*)
+				swexec_status=0
+				$xvr_fname "$line"
+				case "$?" in
+					0)
+						xvr_sw_retval=0
+						;;
+					*)
+						xvr_sw_retval=0
+						;;
+				esac
+				;;
+		esac
+	done
+	return "$xvr_sw_retval"
+}
+
 shls__cleansh() {
 	(
 		# ps -axw should work on GNU/Linux and BSD hosts
 		# ps -elf will be used on OpenSolaris
-		ps -axw 2>/dev/null || ps -elf
+		ps axw 2>/dev/null || ps -elf
 	) | awk -- '
 	BEGIN {
 		FS=" ";
