@@ -75,7 +75,7 @@ ahsStaticSetTarname_length_i(STROB ** c_sb, int len)
 
 
 static void
-ahsStaticSetTarname_i(STROB ** c_sb, char * name)
+ahsStaticSetTarname_i(STROB ** c_sb, char * name, int len)
 {
 	AHS_E_DEBUG("");
 	if (name == NULL) {
@@ -87,7 +87,15 @@ ahsStaticSetTarname_i(STROB ** c_sb, char * name)
 	if (*c_sb == NULL) {
 		*c_sb = strob_open(100);
 	}
-	strob_strcpy(*c_sb, name);
+	if (len < 0) {
+		/* Nul terminated of undetermined length */
+		if (name != (char*)((*c_sb)->str_)) strob_strcpy(*c_sb, name);
+	} else {
+		/* Copy at most len bytes, NUL terminate at len+1 */
+		strob_set_memlength(*c_sb, len+1);
+		if (name != (char*)((*c_sb)->str_)) strob_strncpy(*c_sb, name, len);
+		*(strob_str(*c_sb) + len) = '\0';
+	}
 	return;
 }
 
@@ -96,7 +104,7 @@ ahsStaticGetTarname_i(STROB ** c_sb)
 {
 	AHS_E_DEBUG("");
 	if (*c_sb == (STROB*)NULL) {
-		ahsStaticSetTarname_i(c_sb, "");
+		ahsStaticSetTarname_i(c_sb, "", -1);
 	}
 	return strob_str(*c_sb);
 }
@@ -209,7 +217,7 @@ ahsStaticCreateFilehdr(void)
 {
 	struct new_cpio_header * file_hdr = taru_make_header();
 	AHS_E_DEBUG("");
-	ahsStaticSetTarLinkname(file_hdr, NULL);
+	ahsStaticSetPaxLinkname(file_hdr, NULL);
 	ahsStaticSetTarFilename(file_hdr, NULL);
 	ahsStaticSetTarUsername(file_hdr, NULL);
 	ahsStaticSetTarGroupname(file_hdr, NULL);
@@ -220,7 +228,7 @@ void
 ahsStaticDeleteFilehdr(struct new_cpio_header * file_hdr)
 {
 	AHS_E_DEBUG("");
-	ahsStaticSetTarLinkname(file_hdr, NULL);
+	ahsStaticSetPaxLinkname(file_hdr, NULL);
 	ahsStaticSetTarFilename(file_hdr, NULL);
 	ahsStaticSetTarUsername(file_hdr, NULL);
 	ahsStaticSetTarGroupname(file_hdr, NULL);
@@ -279,32 +287,44 @@ ahsStaticGetTarGroupname(struct new_cpio_header * file_hdr)
 	return ahsStaticGetTarname_i((STROB**)&(file_hdr->c_groupname));
 }
 
+void
+ahsStaticSetPaxLinkname(struct new_cpio_header * file_hdr, char * name)
+{
+	AHS_E_DEBUG("");
+	ahsStaticSetTarname_i((STROB**)&(file_hdr->c_tar_linkname), name, -1);
+}
+
 void
 ahsStaticSetTarLinkname(struct new_cpio_header * file_hdr, char * name)
 {
 	AHS_E_DEBUG("");
-	ahsStaticSetTarname_i((STROB**)&(file_hdr->c_tar_linkname), name);
+	/*
+ 	 * Deliberately store more than TARLINKNAMESIZE so the routines that censor
+ 	 * this size will see the overlength field and complain.
+ 	 * Use ahsStaticSetPaxLinkname() to set a  long link name
+ 	 */
+	ahsStaticSetTarname_i((STROB**)&(file_hdr->c_tar_linkname), name, TARLINKNAMESIZE);
 }
 
 void
 ahsStaticSetTarFilename(struct new_cpio_header * file_hdr, char * name)
 {
 	AHS_E_DEBUG("");
-	ahsStaticSetTarname_i((STROB**)&(file_hdr->c_name),  name);
+	ahsStaticSetTarname_i((STROB**)&(file_hdr->c_name),  name, -1);
 }
 
 void
 ahsStaticSetTarUsername(struct new_cpio_header * file_hdr, char * name)
 {
 	AHS_E_DEBUG("");
-	ahsStaticSetTarname_i((STROB**)&(file_hdr->c_username),  name);
+	ahsStaticSetTarname_i((STROB**)&(file_hdr->c_username),  name, -1);
 }
 
 void
 ahsStaticSetTarGroupname(struct new_cpio_header * file_hdr, char * name)
 {
 	AHS_E_DEBUG("");
-	ahsStaticSetTarname_i((STROB**)&(file_hdr->c_groupname),  name);
+	ahsStaticSetTarname_i((STROB**)&(file_hdr->c_groupname),  name, -1);
 }
 
 void ahs_close(AHS * xhs) 
@@ -390,7 +410,7 @@ void ahs_set_uid_by_name(AHS * xhs, char * username) {
 		AHS_E_DEBUG("");
 		ahs_vfile_hdr(xhs)->c_uid = (unsigned long)x;
 	}
-	/* ahs_vfile_hdr(xhs)->c_uid = taru_get_user(0, username, NULL); */
+	/* ahs_vfile_hdr(xhs)->c_uid = taru_get_tar_user(0, username, NULL); */
 }
 	
 void ahs_set_gid_by_name(AHS * xhs, char * groupname) { 
@@ -448,10 +468,7 @@ void ahs_set_name(AHS * xhs, char *name) {
     
 void ahs_set_linkname(AHS * xhs, char *linkname) { 
 	AHS_E_DEBUG("");
-	if (strlen(linkname) > 99) {
-		fprintf(stderr, "link target [%s] is too long for tar archives, truncating.\n", linkname);
-	}
-	ahsStaticSetTarLinkname(ahs_vfile_hdr(xhs), linkname);
+	ahsStaticSetPaxLinkname(ahs_vfile_hdr(xhs), linkname);
 }
 
 void ahs_set_from_statbuf(AHS * xhs, struct stat *st) { 
@@ -487,7 +504,7 @@ unsigned ahs_get_tar_chksum(AHS * xhs, void * tarhdr) {
 char* 
 ahs_get_system_username(AHS * xhs, char * buf) {
 	AHS_E_DEBUG("");
-	if (taru_get_user_by_uid(ahs_vfile_hdr(xhs)->c_uid,  buf)) {
+	if (taru_get_tar_user_by_uid(ahs_vfile_hdr(xhs)->c_uid,  buf)) {
 		return NULL;
 	} else {
 		return buf;
@@ -497,7 +514,7 @@ ahs_get_system_username(AHS * xhs, char * buf) {
 char* 
 ahs_get_system_groupname(AHS * xhs, char * buf) {
 	AHS_E_DEBUG("");
-	if (taru_get_group_by_gid(ahs_vfile_hdr(xhs)->c_gid, buf)) {
+	if (taru_get_tar_group_by_gid(ahs_vfile_hdr(xhs)->c_gid, buf)) {
 		return NULL;
 	} else {
 		return buf;
