@@ -36,6 +36,16 @@
 #include "ls_list.h"
 #include "taruib.h"
 
+static
+void
+i_taru_needy_message(char * filename, char * field_name)
+{
+	fprintf(stderr,
+		"%s: %s: %s value too long for selected format\n",
+			swlib_utilname_get(), filename, field_name);
+	return;
+}
+
 TARU * taru_create(void)
 {
 	TARU * taru = (TARU*)malloc(sizeof(TARU));
@@ -225,69 +235,100 @@ taru_digs_init(FILE_DIGS * digs, int enable, int poison)
 	}
 }
 
+/*
 int
 taru_ustar_field_size_check(struct new_cpio_header * file_hdr)
 {
 	int ret;
-	ret = taru_fill_exthdr_needs_mask(file_hdr, /*tarheaderflags*/ 0);
-	return ret; /* 0  means all attributes fit OK */
+	ret = taru_fill_exthdr_needs_mask(file_hdr, 0);
+	return ret; 
 }
+*/
 
 int
-taru_fill_exthdr_needs_mask(struct new_cpio_header * file_hdr, int tarheaderflags)
+taru_fill_exthdr_needs_mask(struct new_cpio_header * file_hdr,
+		int tarheaderflags,
+		int is_pax_header_allowed,
+		int be_verbose)
 {
   	/* file_hdr->extHeader_needs_maskM = 0; */
 	int mask = 0;
 
+
 	/*
 	 * These tests represent tests of the limits of the ustar header fields
 	 */
 
 	if (taru_is_tar_filename_too_long(ahsStaticGetTarFilename(file_hdr),
-						0 /*tarheaderflags*/, 
-						NULL, 0 /*is_dir*/)) {
+						0 /*tarheaderflags ... this disables exceptions
+						   for the gnu formats 
+						   */,
+						NULL /* don't care if gnu_long_links would be used
+						    */, 
+						0    /*is_dir*/))
+	{
+		if (be_verbose && !is_pax_header_allowed)
+			i_taru_needy_message(ahsStaticGetTarFilename(file_hdr), "path");
 	  	mask |=  TARU_EHUM_PATH;
 	}
 
 
 	if (taru_is_tar_linkname_too_long(ahsStaticGetTarLinkname(file_hdr),
 				0 /*tarheaderflags*/, NULL /*&do_gnu_long_link*/)){
+		if (be_verbose && !is_pax_header_allowed)
+			i_taru_needy_message(ahsStaticGetTarFilename(file_hdr), "linkname");
 	  	mask |=  TARU_EHUM_LINKPATH;
 	}
 
 
 	if (file_hdr->c_filesize > TAR_MAX_SIZE) {
+		if (be_verbose && !is_pax_header_allowed)
+			i_taru_needy_message(ahsStaticGetTarFilename(file_hdr), "size");
 		mask |=  TARU_EHUM_SIZE;
 	} 
 
 
 	if (file_hdr->c_uid > TAR_MAX_UID) {
+		if (be_verbose && !is_pax_header_allowed)
+			i_taru_needy_message(ahsStaticGetTarFilename(file_hdr), "uid");
 		mask |=  TARU_EHUM_UID;
 	} 
 
 
-	if (file_hdr->c_gid > TAR_MAX_UID) {
+	if (file_hdr->c_gid > TAR_MAX_GID) {
+		if (be_verbose && !is_pax_header_allowed)
+			i_taru_needy_message(ahsStaticGetTarFilename(file_hdr), "gid");
 		mask |=  TARU_EHUM_GID;
 	} 
 
 
 	if (strlen(ahsStaticGetTarUsername(file_hdr)) >= THB_FL_uname ) {
+		if (be_verbose && !is_pax_header_allowed)
+			i_taru_needy_message(ahsStaticGetTarFilename(file_hdr), "owner name");
 	  	mask |=  TARU_EHUM_UNAME;
 	}
 
 	if (strlen(ahsStaticGetTarGroupname(file_hdr)) >= THB_FL_gname ) {
+		if (be_verbose && !is_pax_header_allowed)
+			i_taru_needy_message(ahsStaticGetTarFilename(file_hdr), "group name");
 	  	mask |=  TARU_EHUM_GNAME;
 	}
 
 	if (file_hdr->c_filesize > TAR_MAX_SIZE) {
+		if (be_verbose && !is_pax_header_allowed)
+			i_taru_needy_message(ahsStaticGetTarFilename(file_hdr), "size");
 		mask |=  TARU_EHUM_SIZE;
 	} 
 
 	if (file_hdr->c_dev_maj > TAR_MAX_DEVICE) {
+		if (be_verbose && !is_pax_header_allowed)
+			i_taru_needy_message(ahsStaticGetTarFilename(file_hdr), "dev maj");
 		mask |=  TARU_EHUM_DEV_MAJ;
 	} 
 
 	if (file_hdr->c_dev_min > TAR_MAX_DEVICE) {
+		if (be_verbose && !is_pax_header_allowed)
+			i_taru_needy_message(ahsStaticGetTarFilename(file_hdr), "dev min");
 		mask |=  TARU_EHUM_DEV_MIN;
 	} 
 
