@@ -300,6 +300,19 @@ minor_to_chars (minor_t v, char *p, size_t s, int archive_format, int termch)
   to_chars (v < 0, (uintmax_t) v, sizeof v, 0, p, s, "minor_t", archive_format, termch);
 }
 
+
+/* JL 2014-06-21
+ * FIXME: this should be handled by autoconf and ./configure.
+ * /usr/include/tar.h seems to have changed in Slackware 1.14
+ * in that #define TSVTX 01000 is now conditionally included.
+ * (TSVTX may be a very old name for this mask value).
+ * There is probably no harm in defining it here.
+ */
+
+#ifndef TSVTX
+# define TSVTX  01000
+#endif
+
 void
 mode_to_chars (mode_t v, char *p, size_t s, int archive_format, int termch)
 {
