@@ -918,8 +918,11 @@ LABEL_REREAD:
 			
 			/* look for gzmagic */
 
-			if (memcmp(((unsigned char*)xbuffer)+deb_gz_offset, (void *)gzmagic, LENGTH_OF_MAGIC) != 0) {
-				fprintf(stderr, "%s: gz magic not found for control.tar.gz\n", swlib_utilname_get());
+			if (
+				memcmp(((unsigned char*)xbuffer)+deb_gz_offset, (void *)gzmagic, LENGTH_OF_MAGIC) != 0 &&
+				memcmp(((unsigned char*)xbuffer)+deb_gz_offset, (void *)xzmamagic, LENGTH_OF_MAGIC) != 0
+			) {
+				fprintf(stderr, "%s: neither gz or xz magic found for control.tar.gz\n", swlib_utilname_get());
 				return -1;
 			}
 		
