@@ -4,7 +4,7 @@
 #include <stdlib.h>
 #include <string>
 #include <typeinfo>
-#include "stream_config.h"
+#include "xstream_config.h"
 #include <assert.h>
 #include "swindex.h"
 #include "swparser.h"
